@@ -18,10 +18,10 @@ class AppTestGenerator(object):
     """
     Test Generator for an App.
     Generates test cases of Fields and CIM.
-    The test generator is to include all the specific test generators. 
+    The test generator is to include all the specific test generators.
 
-    AppTestGenerator should not have any direct generation methods, it should call a specific 
-    test generator methods only. Make sure there is no heavy initialization in __init__, all the 
+    AppTestGenerator should not have any direct generation methods, it should call a specific
+    test generator methods only. Make sure there is no heavy initialization in __init__, all the
     configurations and operations should only take place in generate_tests method.
 
     Args:
@@ -31,9 +31,7 @@ class AppTestGenerator(object):
     def __init__(self, pytest_config):
         self.pytest_config = pytest_config
         self.seen_tests = set()
-        LOGGER.debug(
-            "Initializing FieldTestGenerator to generate the test cases"
-        )
+        LOGGER.debug("Initializing FieldTestGenerator to generate the test cases")
         self.fieldtest_generator = FieldTestGenerator(
             self.pytest_config.getoption("splunk_app"),
             field_bank=self.pytest_config.getoption("field_bank", False),
@@ -42,24 +40,20 @@ class AppTestGenerator(object):
         data_model_path = os.path.join(
             os.path.dirname(os.path.abspath(__file__)), "data_models"
         )
-        LOGGER.debug(
-            "Initializing CIMTestGenerator to generate the test cases"
-        )
+        LOGGER.debug("Initializing CIMTestGenerator to generate the test cases")
         self.cim_test_generator = CIMTestGenerator(
             self.pytest_config.getoption("splunk_app"),
             self.pytest_config.getoption("splunk_dm_path") or data_model_path,
         )
-        LOGGER.debug(
-            "Initializing ReqsTestGenerator to generate the test cases"
-        )
+        LOGGER.debug("Initializing ReqsTestGenerator to generate the test cases")
         self.requirement_test_generator = ReqsTestGenerator(
-            self.pytest_config.getoption("splunk_app"),
+            self.pytest_config.getoption("requirement_test"),
         )
         self.indextime_test_generator = IndexTimeTestGenerator()
 
     def generate_tests(self, fixture):
         """
-        Generate the test cases based on the fixture provided 
+        Generate the test cases based on the fixture provided
         supported fixtures:
 
         * splunk_app_searchtime_*
@@ -68,7 +62,7 @@ class AppTestGenerator(object):
 
         Args:
             fixture(str): fixture name
-        """ 
+        """
         store_events = self.pytest_config.getoption("store_events")
         if fixture.startswith("splunk_searchtime_fields"):
             yield from self.dedup_tests(
@@ -79,9 +73,10 @@ class AppTestGenerator(object):
                 self.cim_test_generator.generate_tests(fixture), fixture
             )
         elif fixture.startswith("splunk_searchtime_requirement"):
-            yield from self.dedup_tests(
-                self.requirement_test_generator.generate_tests(fixture), fixture
-            )
+            if self.pytest_config.getoption("requirement_test") != "None":
+                yield from self.dedup_tests(
+                    self.requirement_test_generator.generate_tests(fixture), fixture
+                )
         elif fixture.startswith("splunk_indextime"):
             # TODO: What should be the id of the test case?
             # Sourcetype + Host + Key field + _count
@@ -89,7 +84,9 @@ class AppTestGenerator(object):
             pytest_params = None
 
             app_path = self.pytest_config.getoption("splunk_app")
-            config_path = config_path = self.pytest_config.getoption("splunk_data_generator")
+            config_path = config_path = self.pytest_config.getoption(
+                "splunk_data_generator"
+            )
 
             if "key_fields" in fixture:
                 pytest_params = list(
@@ -97,8 +94,8 @@ class AppTestGenerator(object):
                         store_events,
                         app_path=app_path,
                         config_path=config_path,
-                        test_type="key_fields"
-                        )
+                        test_type="key_fields",
+                    )
                 )
 
             elif "_time" in fixture:
@@ -107,8 +104,8 @@ class AppTestGenerator(object):
                         store_events,
                         app_path=app_path,
                         config_path=config_path,
-                        test_type="_time"
-                        )
+                        test_type="_time",
+                    )
                 )
 
             elif "line_breaker" in fixture:
@@ -117,8 +114,8 @@ class AppTestGenerator(object):
                         store_events,
                         app_path=app_path,
                         config_path=config_path,
-                        test_type="line_breaker"
-                        )
+                        test_type="line_breaker",
+                    )
                 )
 
             yield from sorted(pytest_params, key=lambda param: param.id)
