@@ -11,6 +11,7 @@ from ..cim_tests import FieldTestHelper
 MAX_TIME_DIFFERENCE = 45
 LOGGER = logging.getLogger("pytest-splunk-addon")
 
+
 class IndexTimeTestTemplate(object):
     """
     Test templates to test the index time fields of an App
@@ -65,7 +66,11 @@ class IndexTimeTestTemplate(object):
         if splunk_indextime_key_fields.get("identifier"):
             extra_filter = splunk_indextime_key_fields.get("identifier")
         else:
-            extra_filter = "host IN (\""+"\",\"".join(set(splunk_indextime_key_fields.get("hosts")))+"\")"
+            extra_filter = (
+                'host IN ("'
+                + '","'.join(set(splunk_indextime_key_fields.get("hosts")))
+                + '")'
+            )
         fields_to_check = copy.deepcopy(
             splunk_indextime_key_fields["tokenized_event"].key_fields
         )
@@ -78,16 +83,14 @@ class IndexTimeTestTemplate(object):
 
         search = "search {} {}".format(index_list, query)
         record_property("Query", search)
-        LOGGER.debug(
-            "Base search for indextime key field test: {}".format(search))
+        LOGGER.debug("Base search for indextime key field test: {}".format(search))
         results = splunk_search_util.getFieldValuesList(
             search,
             interval=splunk_search_util.search_interval,
             retries=splunk_search_util.search_retry,
         )
         results = list(results)
-        LOGGER.debug(
-            "Results:{}".format(results))
+        LOGGER.debug("Results:{}".format(results))
 
         if not results:
             assert False, "No Events found for query " + search
@@ -110,11 +113,19 @@ class IndexTimeTestTemplate(object):
             value_list, missing_keys = [], []
             for each_field in fields_to_check.keys():
                 if each_field in result_fields.keys():
-                    if not fields_to_check.get(each_field) == result_fields.get(each_field):
-                        value_list.append([each_field, fields_to_check[each_field], result_fields.get(each_field)])
+                    if not fields_to_check.get(each_field) == result_fields.get(
+                        each_field
+                    ):
+                        value_list.append(
+                            [
+                                each_field,
+                                fields_to_check[each_field],
+                                result_fields.get(each_field),
+                            ]
+                        )
                 else:
                     missing_keys.append([each_field, fields_to_check[each_field]])
-            final_str = ''
+            final_str = ""
             if value_list:
                 result_str = FieldTestHelper.get_table_output(
                     headers=["Key_field", "Expected_values", "Actual_values"],
@@ -129,7 +140,7 @@ class IndexTimeTestTemplate(object):
                 )
                 final_str += f"Some values for the following key fields are missing\n\n{result_str}"
 
-            if missing_keys:    
+            if missing_keys:
                 missing_keys_result_str = FieldTestHelper.get_table_output(
                     headers=["Key_field", "Expected_values"],
                     value_list=[
@@ -138,15 +149,14 @@ class IndexTimeTestTemplate(object):
                             str(each_key[1]),
                         ]
                         for each_key in missing_keys
-                    ],     
+                    ],
                 )
                 final_str += f"\n\nSome key fields are not found in search results\n\n{missing_keys_result_str}"
             LOGGER.info(final_str)
 
-            assert int(len(value_list)) == 0 and int(len(missing_keys)) == 0, (
-                f"For this search query: '{search}'\n{final_str}"
-            )
-
+            assert (
+                int(len(value_list)) == 0 and int(len(missing_keys)) == 0
+            ), f"For this search query: '{search}'\n{final_str}"
 
     @pytest.mark.first
     @pytest.mark.splunk_indextime
@@ -175,34 +185,35 @@ class IndexTimeTestTemplate(object):
             + ")"
         )
 
-        assert splunk_indextime_time.get(
-            "identifier"
-        ) or splunk_indextime_time.get(
+        assert splunk_indextime_time.get("identifier") or splunk_indextime_time.get(
             "hosts"
         ), "Host or identifier fields cannot be determined from the config file.."
         assert splunk_indextime_time[
             "tokenized_event"
-        ].time_values, (
-            "_time field cannot be determined from the config file."
-        )
+        ].time_values, "_time field cannot be determined from the config file."
 
         if splunk_indextime_time.get("identifier"):
             extra_filter = splunk_indextime_time.get("identifier")
         else:
-            extra_filter = "host IN (\""+"\",\"".join(set(splunk_indextime_time.get("hosts")))+"\")"
+            extra_filter = (
+                'host IN ("'
+                + '","'.join(set(splunk_indextime_time.get("hosts")))
+                + '")'
+            )
 
         if splunk_indextime_time["tokenized_event"].time_values:
             extra_filter += " | eval e_time=_time"
 
         query = "sourcetype={} {} | table {}".format(
-            splunk_indextime_time.get("sourcetype"), extra_filter, "e_time",
+            splunk_indextime_time.get("sourcetype"),
+            extra_filter,
+            "e_time",
         )
 
         search = "search {} {}".format(index_list, query)
 
         record_property("Query", search)
-        LOGGER.debug(
-            "Base search for indextime time field test: {}".format(search))
+        LOGGER.debug("Base search for indextime time field test: {}".format(search))
         results = splunk_search_util.getFieldValuesList(
             search,
             interval=splunk_search_util.search_interval,
@@ -217,8 +228,9 @@ class IndexTimeTestTemplate(object):
             for key in results[0].keys()
         }
 
-        key_time = [ceil(t) for t in splunk_indextime_time[
-            "tokenized_event"].time_values]
+        key_time = [
+            ceil(t) for t in splunk_indextime_time["tokenized_event"].time_values
+        ]
         result_fields["e_time"].sort()
         key_time.sort()
 
@@ -231,7 +243,6 @@ class IndexTimeTestTemplate(object):
             key_time, result_fields["e_time"]
         )
 
-
     @pytest.mark.first
     @pytest.mark.splunk_indextime
     def test_indextime_line_breaker(
@@ -261,16 +272,13 @@ class IndexTimeTestTemplate(object):
             + " OR index=".join(splunk_search_util.search_index.split(","))
             + ")"
         )
-        host = "(\""+"\",\"".join(splunk_indextime_line_breaker.get("host"))+"\")"
+        host = '("' + '","'.join(splunk_indextime_line_breaker.get("host")) + '")'
         query = "search {} sourcetype={} host IN {} | stats count".format(
-            index_list,
-            splunk_indextime_line_breaker.get("sourcetype"),
-            host
+            index_list, splunk_indextime_line_breaker.get("sourcetype"), host
         )
         record_property("Query", query)
 
-        LOGGER.debug(
-            "Base search for indextime key field test: {}".format(query))
+        LOGGER.debug("Base search for indextime key field test: {}".format(query))
         results = list(
             splunk_search_util.getFieldValuesList(
                 query,
@@ -279,8 +287,7 @@ class IndexTimeTestTemplate(object):
             )
         )
         count_from_results = int(results[0].get("count"))
-        LOGGER.debug(
-            "Resulting count:{}".format(count_from_results))
+        LOGGER.debug("Resulting count:{}".format(count_from_results))
         assert (
             count_from_results == expected_events_count
         ), f"Query: {query} \nExpected count: {expected_events_count} Actual Count: {count_from_results}"
